==> infima_client-0.39.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_cohort_summary.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_service_get_cohort_summary_response_200 import (
    CohortService_GetCohortSummaryResponse_200,
)
from ...models.cohort_service_get_cohort_summary_response_401 import (
    CohortService_GetCohortSummaryResponse_401,
)
from ...models.cohort_service_get_cohort_summary_response_404 import (
    CohortService_GetCohortSummaryResponse_404,
)
from ...models.cohort_service_get_cohort_summary_response_500 import (
    CohortService_GetCohortSummaryResponse_500,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/summary".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    params: Dict[str, Any] = {
        "cohort": cohort,
        "date.year": dateyear,
        "date.month": datemonth,
        "date.day": dateday,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortService_GetCohortSummaryResponse_200,
        CohortService_GetCohortSummaryResponse_401,
        CohortService_GetCohortSummaryResponse_404,
        CohortService_GetCohortSummaryResponse_500,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortService_GetCohortSummaryResponse_200.from_dict(
            response.json()
        )

        return response_200
    if response.status_code == 401:
        response_401 = CohortService_GetCohortSummaryResponse_401.from_dict(
            response.json()
        )

        return response_401
    if response.status_code == 404:
        response_404 = CohortService_GetCohortSummaryResponse_404.from_dict(
            response.json()
        )

        return response_404
    if response.status_code == 500:
        response_500 = CohortService_GetCohortSummaryResponse_500.from_dict(
            response.json()
        )

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortService_GetCohortSummaryResponse_200,
        CohortService_GetCohortSummaryResponse_401,
        CohortService_GetCohortSummaryResponse_404,
        CohortService_GetCohortSummaryResponse_500,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortService_GetCohortSummaryResponse_200,
        CohortService_GetCohortSummaryResponse_401,
        CohortService_GetCohortSummaryResponse_404,
        CohortService_GetCohortSummaryResponse_500,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cohort=cohort,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortService_GetCohortSummaryResponse_200,
        CohortService_GetCohortSummaryResponse_401,
        CohortService_GetCohortSummaryResponse_404,
        CohortService_GetCohortSummaryResponse_500,
    ]
]:
    """


    Args:
        cohort: None
        dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
    """

    return sync_detailed(
        client=client,
        cohort=cohort,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortService_GetCohortSummaryResponse_200,
        CohortService_GetCohortSummaryResponse_401,
        CohortService_GetCohortSummaryResponse_404,
        CohortService_GetCohortSummaryResponse_500,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cohort=cohort,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortService_GetCohortSummaryResponse_200,
        CohortService_GetCohortSummaryResponse_401,
        CohortService_GetCohortSummaryResponse_404,
        CohortService_GetCohortSummaryResponse_500,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )
    ).parsed

==> infima_client-0.45.0-py3-none-any.whl: infima_client/api/cohort_service/cohort_service_get_cohort_summary.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.cohort_summary import CohortSummary
from ...models.cohort_summary_error import CohortSummaryError
from ...models.cohort_summary_not_found import CohortSummaryNotFound
from ...models.cohort_summary_unauthorized import CohortSummaryUnauthorized
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/cohorts/summary".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    params: Dict[str, Any] = {
        "cohort": cohort,
        "date.year": dateyear,
        "date.month": datemonth,
        "date.day": dateday,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        CohortSummary,
        CohortSummaryUnauthorized,
        CohortSummaryNotFound,
        CohortSummaryError,
    ]
]:
    if response.status_code == 200:
        response_200 = CohortSummary.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = CohortSummaryUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = CohortSummaryNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = CohortSummaryError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        CohortSummary,
        CohortSummaryUnauthorized,
        CohortSummaryNotFound,
        CohortSummaryError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortSummary,
        CohortSummaryUnauthorized,
        CohortSummaryNotFound,
        CohortSummaryError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cohort=cohort,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortSummary,
        CohortSummaryUnauthorized,
        CohortSummaryNotFound,
        CohortSummaryError,
    ]
]:
    """


    Args:
        cohort: None
        dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
    """

    return sync_detailed(
        client=client,
        cohort=cohort,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        CohortSummary,
        CohortSummaryUnauthorized,
        CohortSummaryNotFound,
        CohortSummaryError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cohort=cohort,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cohort: Union[Unset, str] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        CohortSummary,
        CohortSummaryUnauthorized,
        CohortSummaryNotFound,
        CohortSummaryError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cohort=cohort,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )
    ).parsed
